image

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckImage

func CheckImage(readSeeker io.ReadSeeker) (string, bool)

CheckImage validates whether the stream looks like an image payload.

func EncodeImage

func EncodeImage(data []byte) ([]byte, error)

EncodeImage converts unsupported image formats to a compatible format.

func IsGIFOrPNGOrJPG

func IsGIFOrPNGOrJPG(file []byte) bool

IsGIFOrPNGOrJPG reports whether the binary data looks like GIF/PNG/JPG.

Types

This section is empty.

Jump to