Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckImage ¶
func CheckImage(readSeeker io.ReadSeeker) (string, bool)
CheckImage validates whether the stream looks like an image payload.
func EncodeImage ¶
EncodeImage converts unsupported image formats to a compatible format.
func IsGIFOrPNGOrJPG ¶
IsGIFOrPNGOrJPG reports whether the binary data looks like GIF/PNG/JPG.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.